Session class
User session
Constructors
Properties
- createdAt → DateTime
-
final
-
data
→ Map<
String, dynamic> -
final
- duration → Duration
-
Get session duration
no setter
- expiresAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isExpired → bool
-
Check if session is expired
no setter
- remainingTime → Duration
-
Get remaining time
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convert to JSON
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited